Enum rmp::decode::value_ref::Error [] [src]

pub enum Error<'r> {
    InvalidMarkerRead(ReadError),
    InvalidLengthRead(ReadError),
    InvalidDataRead(ReadError),
    InvalidLengthSize,
    InvalidUtf8(&'r [u8]Utf8Error),
    InvalidExtTypeRead(ReadError),
    TypeMismatch,
}

Variants

Failed to read the type marker value.

Failed to read string/array/map size.

Failed to read packed non-marker data.

Failed to cast the length read to machine size.

Failed to interpret a byte slice as a UTF-8 string.

Contains untouched bytearray with the underlying decoding error.

Failed to read ext type.

Using Reserved type found.