Enum rmp::decode::value_ref::Error
[−]
[src]
pub enum Error<'r> {
InvalidMarkerRead(ReadError),
InvalidLengthRead(ReadError),
InvalidDataRead(ReadError),
InvalidLengthSize,
InvalidUtf8(&'r [u8], Utf8Error),
InvalidExtTypeRead(ReadError),
TypeMismatch,
}Variants
InvalidMarkerRead(ReadError)Failed to read the type marker value.
InvalidLengthRead(ReadError)Failed to read string/array/map size.
InvalidDataRead(ReadError)Failed to read packed non-marker data.
InvalidLengthSizeFailed to cast the length read to machine size.
InvalidUtf8(&'r [u8], Utf8Error)Failed to interpret a byte slice as a UTF-8 string.
Contains untouched bytearray with the underlying decoding error.
InvalidExtTypeRead(ReadError)Failed to read ext type.
TypeMismatchUsing Reserved type found.